pygments-lexer-clean
====================

A Pygments lexer for the Clean language

This lexer was originally in the Pygments repository (and an older version is
still present there), but now that the maintainers don't regularly check PRs it
is easier to have the lexer in a separate repository.

See PyPi: https://pypi.python.org/pypi/pygments-lexer-clean

Source code: https://gitlab.com/cloogle/archived/pygments-lexer-clean
